@@ -14,7 +14,13 @@ from django_perf_rec.yaml import KVFile
 record_current = local()
 
 
-def record(*, record_name=None, path=None, capture_traceback=None):
+def record(
+    *,
+    record_name=None,
+    path=None,
+    capture_traceback=None,
+    capture_operation=None,
+):
     # Lazy since we may not need this to determine record_name or path,
     # depending on logic below
     test_details = SimpleLazyObject(current_test)
@@ -41,7 +47,12 @@ def record(*, record_name=None, path=None, capture_traceback=None):
             file_name=file_name,
         )
 
-    return PerformanceRecorder(file_name, record_name, capture_traceback)
+    return PerformanceRecorder(
+        file_name,
+        record_name,
+        capture_traceback,
+        capture_operation,
+    )
 
 
 def get_perf_path(file_path):
@@ -73,13 +84,14 @@ def get_record_name(test_name, class_name=None, file_name=""):
 
 
 class PerformanceRecorder:
-    def __init__(self, file_name, record_name, capture_traceback):
+    def __init__(self, file_name, record_name, capture_traceback, capture_operation):
         self.file_name = file_name
         self.record_name = record_name
 
         self.record = []
         self.db_recorder = AllDBRecorder(self.on_op)
         self.cache_recorder = AllCacheRecorder(self.on_op)
+        self.capture_operation = capture_operation
         self.capture_traceback = capture_traceback
 
     def __enter__(self):
@@ -97,6 +109,9 @@ class PerformanceRecorder:
     def on_op(self, op):
         record = {op.name: op.query}
 
+        if self.capture_operation and not self.capture_operation(op):
+            return
+
         if self.capture_traceback and self.capture_traceback(op):
             record["traceback"] = traceback.StackSummary.from_list(
                 op.traceback
